HooksEasy class
Constructors
Properties
- debug ↔ bool
-
Debug mode to print error logs
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
Request headers
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
Webhook API
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
{required Map< String, dynamic> data}) → Future<Map?> - Send request
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited